==> qbittorrent_4.0.3.orig.tar.xz: qbittorrent-4.0.3/src/gui/scanfoldersdelegate.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  sledgehammer999
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * Contact : hammered999@gmail.com
 */

#ifndef SCANFOLDERSDELEGATE_H
#define SCANFOLDERSDELEGATE_H

#include <QItemDelegate>

class QPainter;
class QModelIndex;
class QStyleOptionViewItem;
class QAbstractItemModel;
class PropertiesWidget;
class QTreeView;

class ScanFoldersDelegate : public QItemDelegate
{
    Q_OBJECT

public:
    ScanFoldersDelegate(QObject *parent, QTreeView *foldersView);

private slots:
    void comboboxIndexChanged(int index);

private:
    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &) const;
    void setEditorData(QWidget *editor, const QModelIndex &index) const;
    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &index) const;

    QTreeView *m_folderView;
};

#endif // SCANFOLDERSDELEGATE_H

==> qbittorrent_4.1.7.orig.tar.xz: qbittorrent-4.1.7/src/gui/scanfoldersdelegate.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  sledgehammer999 <hammered999@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef SCANFOLDERSDELEGATE_H
#define SCANFOLDERSDELEGATE_H

#include <QItemDelegate>

class QAbstractItemModel;
class QModelIndex;
class QPainter;
class QStyleOptionViewItem;
class QTreeView;
class PropertiesWidget;

class ScanFoldersDelegate : public QItemDelegate
{
    Q_OBJECT

public:
    ScanFoldersDelegate(QObject *parent, QTreeView *foldersView);

private slots:
    void comboboxIndexChanged(int index);

private:
    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &) const override;
    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &index) const override;

    QTreeView *m_folderView;
};

#endif // SCANFOLDERSDELEGATE_H
